==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/TumblingWindowTriggerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerArgs.builder
import com.pulumi.azurenative.datafactory.kotlin.enums.TumblingWindowFrequency
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Trigger that schedules pipeline runs for all fixed time interval windows from a start time without gaps and also supports backfill scenarios (when start time is in the past).
 * @property annotations List of tags that can be used for describing the trigger.
 * @property delay Specifies how long the trigger waits past due time before triggering new run. It doesn't alter window start and end time. The default is 0. Type: string (or Expression with resultType string), pattern: ((\d+)\.)?(\d\d):(60|([0-5][0-9])):(60|([0-5][0-9])).
 * @property dependsOn Triggers that this trigger depends on. Only tumbling window triggers are supported.
 * @property description Trigger description.
 * @property endTime The end time for the time period for the trigger during which events are fired for windows that are ready. Only UTC time is currently supported.
 * @property frequency The frequency of the time windows.
 * @property interval The interval of the time windows. The minimum interval allowed is 15 Minutes.
 * @property maxConcurrency The max number of parallel time windows (ready for execution) for which a new run is triggered.
 * @property pipeline Pipeline for which runs are created when an event is fired for trigger window that is ready.
 * @property retryPolicy Retry policy that will be applied for failed pipeline runs.
 * @property startTime The start time for the time period for the trigger during which events are fired for windows that are ready. Only UTC time is currently supported.
 * @property type Trigger type.
 * Expected value is 'TumblingWindowTrigger'.
 */
public data class TumblingWindowTriggerArgs(
    public val annotations: Output<List<Any>>? = null,
    public val delay: Output<Any>? = null,
    public val dependsOn: Output<List<Any>>? = null,
    public val description: Output<String>? = null,
    public val endTime: Output<String>? = null,
    public val frequency: Output<Either<String, TumblingWindowFrequency>>,
    public val interval: Output<Int>,
    public val maxConcurrency: Output<Int>,
    public val pipeline: Output<TriggerPipelineReferenceArgs>,
    public val retryPolicy: Output<RetryPolicyArgs>? = null,
    public val startTime: Output<String>,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerArgs =
        com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerArgs.builder()
            .annotations(annotations?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .delay(delay?.applyValue({ args0 -> args0 }))
            .dependsOn(dependsOn?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .description(description?.applyValue({ args0 -> args0 }))
            .endTime(endTime?.applyValue({ args0 -> args0 }))
            .frequency(
                frequency.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .interval(interval.applyValue({ args0 -> args0 }))
            .maxConcurrency(maxConcurrency.applyValue({ args0 -> args0 }))
            .pipeline(pipeline.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .retryPolicy(retryPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .startTime(startTime.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TumblingWindowTriggerArgs].
 */
@PulumiTagMarker
public class TumblingWindowTriggerArgsBuilder internal constructor() {
    private var annotations: Output<List<Any>>? = null

    private var delay: Output<Any>? = null

    private var dependsOn: Output<List<Any>>? = null

    private var description: Output<String>? = null

    private var endTime: Output<String>? = null

    private var frequency: Output<Either<String, TumblingWindowFrequency>>? = null

    private var interval: Output<Int>? = null

    private var maxConcurrency: Output<Int>? = null

    private var pipeline: Output<TriggerPipelineReferenceArgs>? = null

    private var retryPolicy: Output<RetryPolicyArgs>? = null

    private var startTime: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value List of tags that can be used for describing the trigger.
     */
    @JvmName("trjbrjmgkmxdbdpy")
    public suspend fun annotations(`value`: Output<List<Any>>) {
        this.annotations = value
    }

    @JvmName("qissgtxhxakqncfm")
    public suspend fun annotations(vararg values: Output<Any>) {
        this.annotations = Output.all(values.asList())
    }

    /**
     * @param values List of tags that can be used for describing the trigger.
     */
    @JvmName("tiqnsquurqgvbrjq")
    public suspend fun annotations(values: List<Output<Any>>) {
        this.annotations = Output.all(values)
    }

    /**
     * @param value Specifies how long the trigger waits past due time before triggering new run. It doesn't alter window start and end time. The default is 0. Type: string (or Expression with resultType string), pattern: ((\d+)\.)?(\d\d):(60|([0-5][0-9])):(60|([0-5][0-9])).
     */
    @JvmName("atvqqkiiucrjipxs")
    public suspend fun delay(`value`: Output<Any>) {
        this.delay = value
    }

    /**
     * @param value Triggers that this trigger depends on. Only tumbling window triggers are supported.
     */
    @JvmName("yfrlcvtivxtlkpwm")
    public suspend fun dependsOn(`value`: Output<List<Any>>) {
        this.dependsOn = value
    }

    @JvmName("fnxifbtefubooxmi")
    public suspend fun dependsOn(vararg values: Output<Any>) {
        this.dependsOn = Output.all(values.asList())
    }

    /**
     * @param values Triggers that this trigger depends on. Only tumbling window triggers are supported.
     */
    @JvmName("vecgjpixnhlwggxo")
    public suspend fun dependsOn(values: List<Output<Any>>) {
        this.dependsOn = Output.all(values)
    }

    /**
     * @param value Trigger description.
     */
    @JvmName("gquodbiqflbnukhd")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value The end time for the time period for the trigger during which events are fired for windows that are ready. Only UTC time is currently supported.
     */
    @JvmName("iglbbrtcfhnrmirw")
    public suspend fun endTime(`value`: Output<String>) {
        this.endTime = value
    }

    /**
     * @param value The frequency of the time windows.
     */
    @JvmName("xpctoddymbdtglhv")
    public suspend fun frequency(`value`: Output<Either<String, TumblingWindowFrequency>>) {
        this.frequency = value
    }

    /**
     * @param value The interval of the time windows. The minimum interval allowed is 15 Minutes.
     */
    @JvmName("hennajeoehcyvwoc")
    public suspend fun interval(`value`: Output<Int>) {
        this.interval = value
    }

    /**
     * @param value The max number of parallel time windows (ready for execution) for which a new run is triggered.
     */
    @JvmName("hytwjqybsqdodrrm")
    public suspend fun maxConcurrency(`value`: Output<Int>) {
        this.maxConcurrency = value
    }

    /**
     * @param value Pipeline for which runs are created when an event is fired for trigger window that is ready.
     */
    @JvmName("ctbvlnnivsybckpe")
    public suspend fun pipeline(`value`: Output<TriggerPipelineReferenceArgs>) {
        this.pipeline = value
    }

    /**
     * @param value Retry policy that will be applied for failed pipeline runs.
     */
    @JvmName("rwghslvxxftijdcw")
    public suspend fun retryPolicy(`value`: Output<RetryPolicyArgs>) {
        this.retryPolicy = value
    }

    /**
     * @param value The start time for the time period for the trigger during which events are fired for windows that are ready. Only UTC time is currently supported.
     */
    @JvmName("cqmbylleydwuslxh")
    public suspend fun startTime(`value`: Output<String>) {
        this.startTime = value
    }

    /**
     * @param value Trigger type.
     * Expected value is 'TumblingWindowTrigger'.
     */
    @JvmName("evteoapcbtyurvrl")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value List of tags that can be used for describing the trigger.
     */
    @JvmName("cavlxafounktibxm")
    public suspend fun annotations(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param values List of tags that can be used for describing the trigger.
     */
    @JvmName("jvdrwiupwhtmhpvh")
    public suspend fun annotations(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param value Specifies how long the trigger waits past due time before triggering new run. It doesn't alter window start and end time. The default is 0. Type: string (or Expression with resultType string), pattern: ((\d+)\.)?(\d\d):(60|([0-5][0-9])):(60|([0-5][0-9])).
     */
    @JvmName("ifnheqtbsdcfqhla")
    public suspend fun delay(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.delay = mapped
    }

    /**
     * @param value Triggers that this trigger depends on. Only tumbling window triggers are supported.
     */
    @JvmName("vjfuykilpekjtpsw")
    public suspend fun dependsOn(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dependsOn = mapped
    }

    /**
     * @param values Triggers that this trigger depends on. Only tumbling window triggers are supported.
     */
    @JvmName("gehcbsngrhesdyng")
    public suspend fun dependsOn(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dependsOn = mapped
    }

    /**
     * @param value Trigger description.
     */
    @JvmName("qfputuxqqrsamjpa")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value The end time for the time period for the trigger during which events are fired for windows that are ready. Only UTC time is currently supported.
     */
    @JvmName("hdcmgabgdyewenhc")
    public suspend fun endTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endTime = mapped
    }

    /**
     * @param value The frequency of the time windows.
     */
    @JvmName("fyqcwfaqdpnoivel")
    public suspend fun frequency(`value`: Either<String, TumblingWindowFrequency>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.frequency = mapped
    }

    /**
     * @param value The frequency of the time windows.
     */
    @JvmName("wxyrvrjobjlxkjqa")
    public fun frequency(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TumblingWindowFrequency>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.frequency = mapped
    }

    /**
     * @param value The frequency of the time windows.
     */
    @JvmName("beujcepfawheyili")
    public fun frequency(`value`: TumblingWindowFrequency) {
        val toBeMapped = Either.ofRight<String, TumblingWindowFrequency>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.frequency = mapped
    }

    /**
     * @param value The interval of the time windows. The minimum interval allowed is 15 Minutes.
     */
    @JvmName("ftypgxeivdglbgdd")
    public suspend fun interval(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.interval = mapped
    }

    /**
     * @param value The max number of parallel time windows (ready for execution) for which a new run is triggered.
     */
    @JvmName("cnfoitvyiosllpxk")
    public suspend fun maxConcurrency(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.maxConcurrency = mapped
    }

    /**
     * @param value Pipeline for which runs are created when an event is fired for trigger window that is ready.
     */
    @JvmName("royphouujwcaftjx")
    public suspend fun pipeline(`value`: TriggerPipelineReferenceArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.pipeline = mapped
    }

    /**
     * @param argument Pipeline for which runs are created when an event is fired for trigger window that is ready.
     */
    @JvmName("pcbywgtmltnyhqcp")
    public suspend fun pipeline(argument: suspend TriggerPipelineReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = TriggerPipelineReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.pipeline = mapped
    }

    /**
     * @param value Retry policy that will be applied for failed pipeline runs.
     */
    @JvmName("aielebkimmkloefp")
    public suspend fun retryPolicy(`value`: RetryPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retryPolicy = mapped
    }

    /**
     * @param argument Retry policy that will be applied for failed pipeline runs.
     */
    @JvmName("scwucfjvvjfgjwgp")
    public suspend fun retryPolicy(argument: suspend RetryPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = RetryPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retryPolicy = mapped
    }

    /**
     * @param value The start time for the time period for the trigger during which events are fired for windows that are ready. Only UTC time is currently supported.
     */
    @JvmName("frixlqcgmvkefnts")
    public suspend fun startTime(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.startTime = mapped
    }

    /**
     * @param value Trigger type.
     * Expected value is 'TumblingWindowTrigger'.
     */
    @JvmName("aetdahgvmprchgoi")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): TumblingWindowTriggerArgs = TumblingWindowTriggerArgs(
        annotations = annotations,
        delay = delay,
        dependsOn = dependsOn,
        description = description,
        endTime = endTime,
        frequency = frequency ?: throw PulumiNullFieldException("frequency"),
        interval = interval ?: throw PulumiNullFieldException("interval"),
        maxConcurrency = maxConcurrency ?: throw PulumiNullFieldException("maxConcurrency"),
        pipeline = pipeline ?: throw PulumiNullFieldException("pipeline"),
        retryPolicy = retryPolicy,
        startTime = startTime ?: throw PulumiNullFieldException("startTime"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/TumblingWindowTriggerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerArgs.builder
import com.pulumi.azurenative.datafactory.kotlin.enums.TumblingWindowFrequency
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Trigger that schedules pipeline runs for all fixed time interval windows from a start time without gaps and also supports backfill scenarios (when start time is in the past).
 * @property annotations List of tags that can be used for describing the trigger.
 * @property delay Specifies how long the trigger waits past due time before triggering new run. It doesn't alter window start and end time. The default is 0. Type: string (or Expression with resultType string), pattern: ((\d+)\.)?(\d\d):(60|([0-5][0-9])):(60|([0-5][0-9])).
 * @property dependsOn Triggers that this trigger depends on. Only tumbling window triggers are supported.
 * @property description Trigger description.
 * @property endTime The end time for the time period for the trigger during which events are fired for windows that are ready. Only UTC time is currently supported.
 * @property frequency The frequency of the time windows.
 * @property interval The interval of the time windows. The minimum interval allowed is 15 Minutes.
 * @property maxConcurrency The max number of parallel time windows (ready for execution) for which a new run is triggered.
 * @property pipeline Pipeline for which runs are created when an event is fired for trigger window that is ready.
 * @property retryPolicy Retry policy that will be applied for failed pipeline runs.
 * @property startTime The start time for the time period for the trigger during which events are fired for windows that are ready. Only UTC time is currently supported.
 * @property type Trigger type.
 * Expected value is 'TumblingWindowTrigger'.
 */
public data class TumblingWindowTriggerArgs(
    public val annotations: Output<List<Any>>? = null,
    public val delay: Output<Any>? = null,
    public val dependsOn: Output<List<Any>>? = null,
    public val description: Output<String>? = null,
    public val endTime: Output<String>? = null,
    public val frequency: Output<Either<String, TumblingWindowFrequency>>,
    public val interval: Output<Int>,
    public val maxConcurrency: Output<Int>,
    public val pipeline: Output<TriggerPipelineReferenceArgs>,
    public val retryPolicy: Output<RetryPolicyArgs>? = null,
    public val startTime: Output<String>,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerArgs =
        com.pulumi.azurenative.datafactory.inputs.TumblingWindowTriggerArgs.builder()
            .annotations(annotations?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .delay(delay?.applyValue({ args0 -> args0 }))
            .dependsOn(dependsOn?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .description(description?.applyValue({ args0 -> args0 }))
            .endTime(endTime?.applyValue({ args0 -> args0 }))
            .frequency(
                frequency.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .interval(interval.applyValue({ args0 -> args0 }))
            .maxConcurrency(maxConcurrency.applyValue({ args0 -> args0 }))
            .pipeline(pipeline.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .retryPolicy(retryPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .startTime(startTime.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TumblingWindowTriggerArgs].
 */
@PulumiTagMarker
public class TumblingWindowTriggerArgsBuilder internal constructor() {
    private var annotations: Output<List<Any>>? = null

    private var delay: Output<Any>? = null

    private var dependsOn: Output<List<Any>>? = null

    private var description: Output<String>? = null

    private var endTime: Output<String>? = null

    private var frequency: Output<Either<String, TumblingWindowFrequency>>? = null

    private var interval: Output<Int>? = null

    private var maxConcurrency: Output<Int>? = null

    private var pipeline: Output<TriggerPipelineReferenceArgs>? = null

    private var retryPolicy: Output<RetryPolicyArgs>? = null

    private var startTime: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value List of tags that can be used for describing the trigger.
     */
    @JvmName("wopymhbnlxsxyden")
    public suspend fun annotations(`value`: Output<List<Any>>) {
        this.annotations = value
    }

    @JvmName("hhxmlykesbxmrlpq")
    public suspend fun annotations(vararg values: Output<Any>) {
        this.annotations = Output.all(values.asList())
    }

    /**
     * @param values List of tags that can be used for describing the trigger.
     */
    @JvmName("cresuhrlpxhisvdt")
    public suspend fun annotations(values: List<Output<Any>>) {
        this.annotations = Output.all(values)
    }

    /**
     * @param value Specifies how long the trigger waits past due time before triggering new run. It doesn't alter window start and end time. The default is 0. Type: string (or Expression with resultType string), pattern: ((\d+)\.)?(\d\d):(60|([0-5][0-9])):(60|([0-5][0-9])).
     */
    @JvmName("evghvhwdfkoolqpb")
    public suspend fun delay(`value`: Output<Any>) {
        this.delay = value
    }

    /**
     * @param value Triggers that this trigger depends on. Only tumbling window triggers are supported.
     */
    @JvmName("tcdqvbwsmlpvipcm")
    public suspend fun dependsOn(`value`: Output<List<Any>>) {
        this.dependsOn = value
    }

    @JvmName("lwnxdssffxlichom")
    public suspend fun dependsOn(vararg values: Output<Any>) {
        this.dependsOn = Output.all(values.asList())
    }

    /**
     * @param values Triggers that this trigger depends on. Only tumbling window triggers are supported.
     */
    @JvmName("uemfpbyxbkucsllb")
    public suspend fun dependsOn(values: List<Output<Any>>) {
        this.dependsOn = Output.all(values)
    }

    /**
     * @param value Trigger description.
     */
    @JvmName("wxnsqujqorospjki")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value The end time for the time period for the trigger during which events are fired for windows that are ready. Only UTC time is currently supported.
     */
    @JvmName("jugkhbdfjcaukisk")
    public suspend fun endTime(`value`: Output<String>) {
        this.endTime = value
    }

    /**
     * @param value The frequency of the time windows.
     */
    @JvmName("cfdlvmlsmtcxkobt")
    public suspend fun frequency(`value`: Output<Either<String, TumblingWindowFrequency>>) {
        this.frequency = value
    }

    /**
     * @param value The interval of the time windows. The minimum interval allowed is 15 Minutes.
     */
    @JvmName("gjbogkcmhrguiowa")
    public suspend fun interval(`value`: Output<Int>) {
        this.interval = value
    }

    /**
     * @param value The max number of parallel time windows (ready for execution) for which a new run is triggered.
     */
    @JvmName("ldscmjnpugnnovbc")
    public suspend fun maxConcurrency(`value`: Output<Int>) {
        this.maxConcurrency = value
    }

    /**
     * @param value Pipeline for which runs are created when an event is fired for trigger window that is ready.
     */
    @JvmName("ailgugbqbyporjtv")
    public suspend fun pipeline(`value`: Output<TriggerPipelineReferenceArgs>) {
        this.pipeline = value
    }

    /**
     * @param value Retry policy that will be applied for failed pipeline runs.
     */
    @JvmName("fvjcsugjgcyuvsns")
    public suspend fun retryPolicy(`value`: Output<RetryPolicyArgs>) {
        this.retryPolicy = value
    }

    /**
     * @param value The start time for the time period for the trigger during which events are fired for windows that are ready. Only UTC time is currently supported.
     */
    @JvmName("aybqudmrsmfcomli")
    public suspend fun startTime(`value`: Output<String>) {
        this.startTime = value
    }

    /**
     * @param value Trigger type.
     * Expected value is 'TumblingWindowTrigger'.
     */
    @JvmName("gaxscsinvukpviit")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value List of tags that can be used for describing the trigger.
     */
    @JvmName("tvrfwqehuewsbxjy")
    public suspend fun annotations(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param values List of tags that can be used for describing the trigger.
     */
    @JvmName("jxbvqprulapkcaqc")
    public suspend fun annotations(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param value Specifies how long the trigger waits past due time before triggering new run. It doesn't alter window start and end time. The default is 0. Type: string (or Expression with resultType string), pattern: ((\d+)\.)?(\d\d):(60|([0-5][0-9])):(60|([0-5][0-9])).
     */
    @JvmName("ibtstidgodypqvsr")
    public suspend fun delay(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.delay = mapped
    }

    /**
     * @param value Triggers that this trigger depends on. Only tumbling window triggers are supported.
     */
    @JvmName("uggfjpitfjwuxyms")
    public suspend fun dependsOn(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dependsOn = mapped
    }

    /**
     * @param values Triggers that this trigger depends on. Only tumbling window triggers are supported.
     */
    @JvmName("vnitkwuaqocwmlkv")
    public suspend fun dependsOn(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dependsOn = mapped
    }

    /**
     * @param value Trigger description.
     */
    @JvmName("vrckdgpwfmagcgyc")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value The end time for the time period for the trigger during which events are fired for windows that are ready. Only UTC time is currently supported.
     */
    @JvmName("ywiokcldagqesygy")
    public suspend fun endTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endTime = mapped
    }

    /**
     * @param value The frequency of the time windows.
     */
    @JvmName("hkbpgdgxvynekftf")
    public suspend fun frequency(`value`: Either<String, TumblingWindowFrequency>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.frequency = mapped
    }

    /**
     * @param value The frequency of the time windows.
     */
    @JvmName("jwgvqeolrookjwuk")
    public fun frequency(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TumblingWindowFrequency>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.frequency = mapped
    }

    /**
     * @param value The frequency of the time windows.
     */
    @JvmName("cdxwpxgaewcskgyf")
    public fun frequency(`value`: TumblingWindowFrequency) {
        val toBeMapped = Either.ofRight<String, TumblingWindowFrequency>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.frequency = mapped
    }

    /**
     * @param value The interval of the time windows. The minimum interval allowed is 15 Minutes.
     */
    @JvmName("ctmhtcyvwejsspvg")
    public suspend fun interval(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.interval = mapped
    }

    /**
     * @param value The max number of parallel time windows (ready for execution) for which a new run is triggered.
     */
    @JvmName("mmfxqtewaobfpabs")
    public suspend fun maxConcurrency(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.maxConcurrency = mapped
    }

    /**
     * @param value Pipeline for which runs are created when an event is fired for trigger window that is ready.
     */
    @JvmName("txbwygmmdvkhdmji")
    public suspend fun pipeline(`value`: TriggerPipelineReferenceArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.pipeline = mapped
    }

    /**
     * @param argument Pipeline for which runs are created when an event is fired for trigger window that is ready.
     */
    @JvmName("sybgblbixsafrbcc")
    public suspend fun pipeline(argument: suspend TriggerPipelineReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = TriggerPipelineReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.pipeline = mapped
    }

    /**
     * @param value Retry policy that will be applied for failed pipeline runs.
     */
    @JvmName("vvwugefxnihuqmdj")
    public suspend fun retryPolicy(`value`: RetryPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retryPolicy = mapped
    }

    /**
     * @param argument Retry policy that will be applied for failed pipeline runs.
     */
    @JvmName("vxusvalfsatfakpq")
    public suspend fun retryPolicy(argument: suspend RetryPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = RetryPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retryPolicy = mapped
    }

    /**
     * @param value The start time for the time period for the trigger during which events are fired for windows that are ready. Only UTC time is currently supported.
     */
    @JvmName("bqfxlxgbtdpqagjm")
    public suspend fun startTime(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.startTime = mapped
    }

    /**
     * @param value Trigger type.
     * Expected value is 'TumblingWindowTrigger'.
     */
    @JvmName("mhrvmpwylwnbyqto")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): TumblingWindowTriggerArgs = TumblingWindowTriggerArgs(
        annotations = annotations,
        delay = delay,
        dependsOn = dependsOn,
        description = description,
        endTime = endTime,
        frequency = frequency ?: throw PulumiNullFieldException("frequency"),
        interval = interval ?: throw PulumiNullFieldException("interval"),
        maxConcurrency = maxConcurrency ?: throw PulumiNullFieldException("maxConcurrency"),
        pipeline = pipeline ?: throw PulumiNullFieldException("pipeline"),
        retryPolicy = retryPolicy,
        startTime = startTime ?: throw PulumiNullFieldException("startTime"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
